@@ -1,5 +1,6 @@
 mod bindings;
 pub mod cli;
+mod cmd_log;
 pub mod config;
 mod git;
 mod git2_opts;
@@ -18,9 +19,8 @@ mod ui;
 use crossterm::event::{self, Event, KeyCode, KeyEvent, KeyEventState, KeyModifiers};
 use git2::Repository;
 use items::Item;
-use itertools::Itertools;
 use ops::Action;
-use std::{borrow::Cow, error::Error, iter, path::PathBuf, process::Command, time::Duration};
+use std::{error::Error, path::PathBuf, process::Command, rc::Rc, time::Duration};
 use term::Term;
 
 //                                An overview of Gitu's ui and terminology:
@@ -62,21 +62,6 @@ use term::Term;
 
 pub type Res<T> = Result<T, Box<dyn Error>>;
 
-pub(crate) enum CmdLogEntry {
-    Cmd {
-        args: Cow<'static, str>,
-        out: Option<Cow<'static, str>>,
-    },
-    Error(String),
-}
-
-fn command_args(cmd: &Command) -> Cow<'static, str> {
-    iter::once(cmd.get_program().to_string_lossy())
-        .chain(cmd.get_args().map(|arg| arg.to_string_lossy()))
-        .join(" ")
-        .into()
-}
-
 pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
     log::debug!("Finding git dir");
     let dir = PathBuf::from(
@@ -97,7 +82,7 @@ pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
     let config = config::init_config()?;
 
     log::debug!("Creating initial state");
-    let mut state = state::State::create(repo, term.size()?, args, config, true)?;
+    let mut state = state::State::create(Rc::new(repo), term.size()?, args, Rc::new(config), true)?;
 
     log::debug!("Initial update");
     state.update(term, &[Event::FocusGained])?;
